@@ -1,5 +1,5 @@
-#ifndef redist_analysis_h
-#define redist_analysis_h
+#ifndef REDIST_ANALYSIS_H
+#define REDIST_ANALYSIS_H
 
 Rcpp::NumericVector segregationcalc(Rcpp::NumericMatrix distmat,
 				    Rcpp::NumericVector grouppop,
